#!/bin/bash
server_url=$1
deploy_key=$2
listen_ip=${3:-0.0.0.0}
listen_port=${4:-8080}

if [ $# -lt 2 ]
    then
        echo "Wrong number of arguments supplied."
        echo "Usage: $0 <server_url> <deploy_key> <listen_ip> <listen_port>."
        echo "listen_ip and listen_port are optional."
        echo "listen_ip default value is 0.0.0.0"
        echo "listen_port default value is 8080"
        exit 1
fi

register(){
server_url=$1
deploy_key=$2
honeypot=$3
hostname=$(hostname)

curl -s -X POST -H "Content-Type: application/json" -d "{
        \"name\": \"${hostname}-${honeypot}\", 
        \"hostname\": \"$hostname\", 
        \"deploy_key\": \"$deploy_key\",
        \"honeypot\": \"$honeypot\"
}" $server_url/api/sensor/ > /tmp/deploy.json

uuid=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["uuid"]')

if [ -z "$uuid" ]
    then
        echo "Could not create sensor using name \"$hostname\"."
        exit 1
fi

set -e

echo "Created sensor: " $uuid

######################################################
# hpfeeds info
export HPF_HOST=$(echo $server_url | sed 's#^http://##; s#^https://##; s#/.*$##; s/:.*$//')
export HPF_PORT="10000"
export HPF_IDENT=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["identifier"]')
export HPF_SECRET=$(python -c 'import json;obj=json.load(file("/tmp/deploy.json"));print obj["secret"]')
######################################################
}

register $server_url $deploy_key "shockpot"

conf=/usr/share/shockpot/shockpot.conf

#Listen IP and Port
sed -i "/^\[server\]/,/^\[/ s/^host.*/host = $listen_ip/"  $conf
sed -i "/^\[server\]/,/^\[/ s/^port.*/port = $listen_port/"  $conf

#HPFEEDS
sed -i "/^\[hpfeeds\]/,/^\[/ s/^enabled.*/enabled = True/"  $conf
sed -i "/^\[hpfeeds\]/,/^\[/ s/^host.*/host = $HPF_HOST/"  $conf
sed -i "/^\[hpfeeds\]/,/^\[/ s/^port.*/port = $HPF_PORT/"  $conf
sed -i "/^\[hpfeeds\]/,/^\[/ s/^identity.*/identity = $HPF_IDENT/"  $conf
sed -i "/^\[hpfeeds\]/,/^\[/ s/^secret.*/secret = $HPF_SECRET/"  $conf


supervisorctl update
supervisorctl restart shockpot
